"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
const StringUtils_1 = require("./util/StringUtils");
const DynatraceNative = react_native_1.NativeModules.DynatraceBridge;
const DynatraceAction_1 = require("./DynatraceAction");
const NullAction_1 = require("./NullAction");
const Debug_1 = require("./Debug");
var counter = 0;
function getCounter() {
    return counter++;
}
exports.Dynatrace = {
    enterAction(name, platform) {
        var key = getCounter();
        if (!StringUtils_1.StringUtils.isStringNullEmptyOrWhitespace(name)) {
            DynatraceNative.enterAction(name, key, platform);
            return new DynatraceAction_1.DynatraceAction(key);
        }
        else {
            Debug_1.Debug.log("Action Name was empty or null! Action will have no effect.");
            return new NullAction_1.NullAction();
        }
    },
    reportError(errorName, errorCode, platform) {
        DynatraceNative.reportErrorWithoutStacktrace(errorName, errorCode, platform);
    },
    reportErrorWithStacktrace(isFatal, errorName, reason, stacktrace, platform) {
        let reasonNewLineIndex = reason.indexOf("\n");
        if (reasonNewLineIndex != -1) {
            reason = reason.substring(0, reasonNewLineIndex);
        }
        if (isFatal) {
            DynatraceNative.reportCrash(errorName, reason, stacktrace, platform);
        }
        else {
            DynatraceNative.reportError(errorName, "-", reason, stacktrace, platform);
        }
    },
    endSession(platform) {
        DynatraceNative.endVisit(platform);
    },
    identifyUser(user, platform) {
        DynatraceNative.identifyUser(user, platform);
    },
    setGPSLocation(latitude, longitude, platform) {
        DynatraceNative.setGPSLocation(latitude, longitude, platform);
    },
    isCrashReportingOptedIn(platform) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield DynatraceNative.isCrashReportingOptedIn(platform);
        });
    },
    setCrashReportingOptedIn(crashReporting, platform) {
        DynatraceNative.setCrashReportingOptedIn(crashReporting, platform);
    },
    getDataCollectionLevel(platform) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield DynatraceNative.getDataCollectionLevel(platform);
        });
    },
    setDataCollectionLevel(dataCollectionLevel, platform) {
        DynatraceNative.setDataCollectionLevel(dataCollectionLevel, platform);
    },
    flushEvents(platform) {
        DynatraceNative.flushEvents(platform);
    }
};
