"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Configuration_1 = require("./Configuration");
exports.LifecycleHelper = (Dynatrace, Logger) => {
    return {
        attachLifycycleListener: function (lifecycleComponent) {
            let componentDidMountOrig;
            if (lifecycleComponent.componentDidMount !== undefined) {
                componentDidMountOrig = lifecycleComponent.componentDidMount.bind(lifecycleComponent);
            }
            lifecycleComponent.componentDidMount = () => {
                this._componentDidMountDynatrace(lifecycleComponent, componentDidMountOrig);
            };
            let componentDidUpdateOrig;
            if (lifecycleComponent.componentDidUpdate !== undefined) {
                componentDidUpdateOrig = lifecycleComponent.componentDidUpdate.bind(lifecycleComponent);
            }
            lifecycleComponent.componentDidUpdate = (prevProps, prevState, snapshot) => {
                this._componentDidUpdateDynatrace(lifecycleComponent, prevProps, prevState, snapshot, componentDidUpdateOrig);
            };
            const renderOrig = lifecycleComponent.render.bind(lifecycleComponent);
            lifecycleComponent.render = () => {
                return this._renderDynatrace(lifecycleComponent, renderOrig);
            };
            let componentWillUnmountOrig;
            if (lifecycleComponent.componentWillUnmount !== undefined) {
                componentWillUnmountOrig = lifecycleComponent.componentWillUnmount.bind(lifecycleComponent);
            }
            lifecycleComponent.componentWillUnmount = () => {
                this._componentWillUnmountDynatrace(lifecycleComponent, componentWillUnmountOrig);
            };
        },
        _componentDidMountDynatrace: function (lifecycleComponent, componentDidMountOrig) {
            if (componentDidMountOrig !== undefined) {
                componentDidMountOrig();
            }
            lifecycleComponent._dynatraceMounted = true;
            if (lifecycleComponent._dynatraceAction !== undefined) {
                let name = getNameFromComponent(lifecycleComponent);
                Logger.log(`Report Event - Component Did Mount - Name: ${name}`);
                lifecycleComponent._dynatraceAction.reportEvent(`${name}.componentDidMount()`);
                lifecycleComponent._dynatraceAction.leaveAction();
                lifecycleComponent._dynatraceAction = undefined;
            }
        },
        _componentDidUpdateDynatrace: function (lifecycleComponent, prevProps, prevState, snapshot, componentDidUpdateOrig) {
            if (componentDidUpdateOrig !== undefined) {
                componentDidUpdateOrig(prevProps, prevState, snapshot);
            }
            if (lifecycleComponent._dynatraceAction !== undefined) {
                let name = getNameFromComponent(lifecycleComponent);
                Logger.log(`Report Event - Component Did Update - Name: ${name}`);
                lifecycleComponent._dynatraceAction.reportEvent(`${name}.componentDidUpdate()`);
                lifecycleComponent._dynatraceAction.leaveAction();
                lifecycleComponent._dynatraceAction = undefined;
            }
        },
        _renderDynatrace: function (lifecycleComponent, renderOrig) {
            if ((lifecycleComponent._dynatraceMounted && Configuration_1.Configuration.isLifecycleUpdateEnabled())
                || (!lifecycleComponent._dynatraceMounted)) {
                let actionPrefix = !lifecycleComponent._dynatraceMounted ? "Render " : "Update ";
                let actionName = getNameFromComponent(lifecycleComponent);
                Logger.log(`Enter Action - ${actionPrefix}- Name: ${actionName}`);
                lifecycleComponent._dynatraceAction = Dynatrace.enterAction(actionPrefix + actionName);
            }
            return renderOrig();
        },
        _componentWillUnmountDynatrace: function (lifecycleComponent, componentWillUnmountOrig) {
            if (componentWillUnmountOrig !== undefined) {
                componentWillUnmountOrig();
            }
            lifecycleComponent._dynatraceMounted = false;
        }
    };
};
function getNameFromComponent(component) {
    if (isConstructorComponentConstructor(component.constructor)) {
        return component.constructor.displayName;
    }
    return component.constructor.name;
}
function isConstructorComponentConstructor(constructor) {
    return constructor.displayName !== undefined;
}
